==> aws-java-sdk-cloudformation-1.10.1-sources.jar: com/amazonaws/services/cloudformation/model/transform/DescribeStacksResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudformation.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudformation.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Describe Stacks Result StAX Unmarshaller
 */
public class DescribeStacksResultStaxUnmarshaller implements Unmarshaller<DescribeStacksResult, StaxUnmarshallerContext> {

    public DescribeStacksResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        DescribeStacksResult describeStacksResult = new DescribeStacksResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return describeStacksResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("Stacks/member", targetDepth)) {
                    describeStacksResult.getStacks().add(StackStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("NextToken", targetDepth)) {
                    describeStacksResult.setNextToken(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeStacksResult;
                }
            }
        }
    }

    private static DescribeStacksResultStaxUnmarshaller instance;
    public static DescribeStacksResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new DescribeStacksResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-java-sdk-cloudformation-1.10.31-sources.jar: com/amazonaws/services/cloudformation/model/transform/DescribeStacksResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.cloudformation.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.cloudformation.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * DescribeStacksResult StAX Unmarshaller
 */
public class DescribeStacksResultStaxUnmarshaller implements
        Unmarshaller<DescribeStacksResult, StaxUnmarshallerContext> {

    public DescribeStacksResult unmarshall(StaxUnmarshallerContext context)
            throws Exception {
        DescribeStacksResult describeStacksResult = new DescribeStacksResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument())
            targetDepth += 2;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument())
                return describeStacksResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {

                if (context.testExpression("Stacks/member", targetDepth)) {
                    describeStacksResult.getStacks().add(
                            StackStaxUnmarshaller.getInstance().unmarshall(
                                    context));
                    continue;
                }

                if (context.testExpression("NextToken", targetDepth)) {
                    describeStacksResult.setNextToken(StringStaxUnmarshaller
                            .getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return describeStacksResult;
                }
            }
        }
    }

    private static DescribeStacksResultStaxUnmarshaller instance;

    public static DescribeStacksResultStaxUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeStacksResultStaxUnmarshaller();
        return instance;
    }
}
